@@ -117,7 +117,7 @@ webkit_pref_callback_user_stylesheet (GSettings  *settings,
     GError *error = NULL;
     char *filename;
 
-    filename = g_build_filename (ephy_dot_dir (), USER_STYLESHEET_FILENAME, NULL);
+    filename = g_build_filename (ephy_profile_dir (), USER_STYLESHEET_FILENAME, NULL);
     file = g_file_new_for_path (filename);
     g_free (filename);
 
@@ -395,6 +395,32 @@ webkit_pref_callback_enable_spell_checking (GSettings  *settings,
   }
 }
 
+static void
+webkit_pref_callback_hardware_acceleration_policy (GSettings  *settings,
+                                                   const char *key,
+                                                   gpointer    data)
+{
+  EphyPrefsWebHardwareAccelerationPolicy value;
+
+  value = g_settings_get_enum (settings, key);
+  switch (value) {
+    case EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ALWAYS:
+      webkit_settings_set_hardware_acceleration_policy (webkit_settings,
+                                                        WEBKIT_HARDWARE_ACCELERATION_POLICY_ALWAYS);
+      break;
+    case EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_NEVER:
+      webkit_settings_set_hardware_acceleration_policy (webkit_settings,
+                                                        WEBKIT_HARDWARE_ACCELERATION_POLICY_NEVER);
+      break;
+    case EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ON_DEMAND:
+      /* Fallthrough */
+    default:
+      webkit_settings_set_hardware_acceleration_policy (webkit_settings,
+                                                        WEBKIT_HARDWARE_ACCELERATION_POLICY_ON_DEMAND);
+      break;
+  }
+}
+
 static const PrefData webkit_pref_entries[] =
 {
   /* Epiphany font settings */
@@ -449,6 +475,10 @@ static const PrefData webkit_pref_entries[] =
     EPHY_PREFS_WEB_COOKIES_POLICY,
     "accept-policy",
     webkit_pref_callback_cookie_accept_policy },
+  { EPHY_PREFS_WEB_SCHEMA,
+    EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY,
+    "hardware-acceleration-policy",
+    webkit_pref_callback_hardware_acceleration_policy },
 };
 
 static gpointer
@@ -464,17 +494,6 @@ ephy_embed_prefs_init (gpointer user_data)
                                                        "javascript-can-open-windows-automatically", TRUE,
                                                        NULL);
 
-  /* Accelerated compositing mode is pretty broken right now.
-   * Disable it entirely as a workaround for these bugs:
-   *
-   * https://bugs.webkit.org/show_bug.cgi?id=192230
-   * https://bugs.webkit.org/show_bug.cgi?id=192276
-   * https://gitlab.gnome.org/GNOME/gtk/issues/1401
-   *
-   * Of course this should be reverted when the bugs are fixed.
-   */
-  webkit_settings_set_hardware_acceleration_policy (webkit_settings, WEBKIT_HARDWARE_ACCELERATION_POLICY_NEVER);
-
   for (i = 0; i < G_N_ELEMENTS (webkit_pref_entries); i++) {
     GSettings *settings;
     char *key;
