@@ -66,9 +66,10 @@ typedef enum
 
 typedef enum
 {
-  EPHY_PREFS_PROCESS_MODEL_SHARED_SECONDARY_PROCESS,
-  EPHY_PREFS_PROCESS_MODEL_ONE_SECONDARY_PROCESS_PER_WEB_VIEW
-} EphyPrefsProcessModel;
+  EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ON_DEMAND,
+  EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_ALWAYS,
+  EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY_NEVER
+} EphyPrefsWebHardwareAccelerationPolicy;
 
 #define EPHY_PREFS_UI_SCHEMA                     "org.gnome.Epiphany.ui"
 #define EPHY_PREFS_UI_EXPAND_TABS_BAR            "expand-tabs-bar"
@@ -95,34 +96,35 @@ static const char * const ephy_prefs_state_schema[] = {
   EPHY_PREFS_STATE_IS_MAXIMIZED
 };
 
-#define EPHY_PREFS_WEB_SCHEMA                      "org.gnome.Epiphany.web"
-#define EPHY_PREFS_WEB_FONT_MIN_SIZE               "min-font-size"
-#define EPHY_PREFS_WEB_LANGUAGE                    "language"
-#define EPHY_PREFS_WEB_USE_GNOME_FONTS             "use-gnome-fonts"
-#define EPHY_PREFS_WEB_SANS_SERIF_FONT             "sans-serif-font"
-#define EPHY_PREFS_WEB_SERIF_FONT                  "serif-font"
-#define EPHY_PREFS_WEB_MONOSPACE_FONT              "monospace-font"
-#define EPHY_PREFS_WEB_ENABLE_USER_CSS             "enable-user-css"
-#define EPHY_PREFS_WEB_ENABLE_POPUPS               "enable-popups"
-#define EPHY_PREFS_WEB_ENABLE_PLUGINS              "enable-plugins"
-#define EPHY_PREFS_WEB_ENABLE_SPELL_CHECKING       "enable-spell-checking"
-#define EPHY_PREFS_WEB_ENABLE_WEBGL                "enable-webgl"
-#define EPHY_PREFS_WEB_ENABLE_WEBAUDIO             "enable-webaudio"
-#define EPHY_PREFS_WEB_ENABLE_SMOOTH_SCROLLING     "enable-smooth-scrolling"
-#define EPHY_PREFS_WEB_USER_AGENT                  "user-agent"
-#define EPHY_PREFS_WEB_COOKIES_POLICY              "cookies-policy"
-#define EPHY_PREFS_WEB_DEFAULT_ENCODING            "default-encoding"
-#define EPHY_PREFS_WEB_DO_NOT_TRACK                "do-not-track"
-#define EPHY_PREFS_WEB_ENABLE_ADBLOCK              "enable-adblock"
-#define EPHY_PREFS_WEB_REMEMBER_PASSWORDS          "remember-passwords"
-#define EPHY_PREFS_WEB_ENABLE_SITE_SPECIFIC_QUIRKS "enable-site-specific-quirks"
-#define EPHY_PREFS_WEB_ENABLE_SAFE_BROWSING        "enable-safe-browsing"
-#define EPHY_PREFS_WEB_GSB_API_KEY                 "gsb-api-key"
-#define EPHY_PREFS_WEB_DEFAULT_ZOOM_LEVEL          "default-zoom-level"
-#define EPHY_PREFS_WEB_ENABLE_AUTOSEARCH           "enable-autosearch"
-#define EPHY_PREFS_WEB_ENABLE_MOUSE_GESTURES       "enable-mouse-gestures"
-#define EPHY_PREFS_WEB_LAST_UPLOAD_DIRECTORY       "last-upload-directory"
-#define EPHY_PREFS_WEB_LAST_DOWNLOAD_DIRECTORY     "last-download-directory"
+#define EPHY_PREFS_WEB_SCHEMA                       "org.gnome.Epiphany.web"
+#define EPHY_PREFS_WEB_FONT_MIN_SIZE                "min-font-size"
+#define EPHY_PREFS_WEB_LANGUAGE                     "language"
+#define EPHY_PREFS_WEB_USE_GNOME_FONTS              "use-gnome-fonts"
+#define EPHY_PREFS_WEB_SANS_SERIF_FONT              "sans-serif-font"
+#define EPHY_PREFS_WEB_SERIF_FONT                   "serif-font"
+#define EPHY_PREFS_WEB_MONOSPACE_FONT               "monospace-font"
+#define EPHY_PREFS_WEB_ENABLE_USER_CSS              "enable-user-css"
+#define EPHY_PREFS_WEB_ENABLE_POPUPS                "enable-popups"
+#define EPHY_PREFS_WEB_ENABLE_PLUGINS               "enable-plugins"
+#define EPHY_PREFS_WEB_ENABLE_SPELL_CHECKING        "enable-spell-checking"
+#define EPHY_PREFS_WEB_ENABLE_WEBGL                 "enable-webgl"
+#define EPHY_PREFS_WEB_ENABLE_WEBAUDIO              "enable-webaudio"
+#define EPHY_PREFS_WEB_ENABLE_SMOOTH_SCROLLING      "enable-smooth-scrolling"
+#define EPHY_PREFS_WEB_USER_AGENT                   "user-agent"
+#define EPHY_PREFS_WEB_COOKIES_POLICY               "cookies-policy"
+#define EPHY_PREFS_WEB_DEFAULT_ENCODING             "default-encoding"
+#define EPHY_PREFS_WEB_DO_NOT_TRACK                 "do-not-track"
+#define EPHY_PREFS_WEB_ENABLE_ADBLOCK               "enable-adblock"
+#define EPHY_PREFS_WEB_REMEMBER_PASSWORDS           "remember-passwords"
+#define EPHY_PREFS_WEB_ENABLE_SITE_SPECIFIC_QUIRKS  "enable-site-specific-quirks"
+#define EPHY_PREFS_WEB_ENABLE_SAFE_BROWSING         "enable-safe-browsing"
+#define EPHY_PREFS_WEB_GSB_API_KEY                  "gsb-api-key"
+#define EPHY_PREFS_WEB_DEFAULT_ZOOM_LEVEL           "default-zoom-level"
+#define EPHY_PREFS_WEB_ENABLE_AUTOSEARCH            "enable-autosearch"
+#define EPHY_PREFS_WEB_ENABLE_MOUSE_GESTURES        "enable-mouse-gestures"
+#define EPHY_PREFS_WEB_LAST_UPLOAD_DIRECTORY        "last-upload-directory"
+#define EPHY_PREFS_WEB_LAST_DOWNLOAD_DIRECTORY      "last-download-directory"
+#define EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY "hardware-acceleration-policy"
 
 static const char * const ephy_prefs_web_schema[] = {
   EPHY_PREFS_WEB_FONT_MIN_SIZE,
@@ -152,22 +154,17 @@ static const char * const ephy_prefs_web_schema[] = {
   EPHY_PREFS_WEB_ENABLE_MOUSE_GESTURES,
   EPHY_PREFS_WEB_LAST_UPLOAD_DIRECTORY,
   EPHY_PREFS_WEB_LAST_DOWNLOAD_DIRECTORY,
+  EPHY_PREFS_WEB_HARDWARE_ACCELERATION_POLICY,
 };
 
 #define EPHY_PREFS_SCHEMA                             "org.gnome.Epiphany"
 #define EPHY_PREFS_HOMEPAGE_URL                       "homepage-url"
-#define EPHY_PREFS_DEPRECATED_USER_AGENT              "user-agent"
 #define EPHY_PREFS_NEW_WINDOWS_IN_TABS                "new-windows-in-tabs"
 #define EPHY_PREFS_WARN_ON_CLOSE_UNSUBMITTED_DATA     "warn-on-close-unsubmitted-data"
-#define EPHY_PREFS_DEPRECATED_REMEMBER_PASSWORDS      "remember-passwords"
-#define EPHY_PREFS_KEYWORD_SEARCH_URL                 "keyword-search-url"
-#define EPHY_PREFS_DEPRECATED_ENABLE_SMOOTH_SCROLLING "enable-smooth-scrolling"
 #define EPHY_PREFS_ENABLE_CARET_BROWSING              "enable-caret-browsing"
 #define EPHY_PREFS_INTERNAL_VIEW_SOURCE               "internal-view-source"
 #define EPHY_PREFS_RESTORE_SESSION_POLICY             "restore-session-policy"
 #define EPHY_PREFS_RESTORE_SESSION_DELAYING_LOADS     "restore-session-delaying-loads"
-#define EPHY_PREFS_PROCESS_MODEL                      "process-model"
-#define EPHY_PREFS_MAX_PROCESSES                      "max-processes"
 #define EPHY_PREFS_ADBLOCK_FILTERS                    "adblock-filters"
 #define EPHY_PREFS_SEARCH_ENGINES                     "search-engines"
 #define EPHY_PREFS_DEFAULT_SEARCH_ENGINE              "default-search-engine"
