@@ -1091,8 +1091,12 @@ css_file_created_cb (GObject      *source,
   stream = g_file_create_finish (file, result, &error);
   if (stream == NULL && !g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
     g_warning ("Failed to create %s: %s", g_file_get_path (file), error->message);
-  else
-    ephy_open_file_via_flatpak_portal (g_file_get_path (file), NULL, css_file_opened_cb, NULL);
+  else {
+    if (ephy_is_running_inside_flatpak ())
+      ephy_open_file_via_flatpak_portal (g_file_get_path (file), NULL, css_file_opened_cb, NULL);
+    else
+      ephy_file_launch_handler (file, gtk_get_current_event_time ());
+  }
 
   if (error != NULL)
     g_error_free (error);
@@ -1107,17 +1111,11 @@ css_edit_button_clicked_cb (GtkWidget   *button,
 {
   GFile *css_file;
 
-  css_file = g_file_new_for_path (g_build_filename (ephy_dot_dir (),
+  css_file = g_file_new_for_path (g_build_filename (ephy_profile_dir (),
                                                     USER_STYLESHEET_FILENAME,
                                                     NULL));
 
-  if (ephy_is_running_inside_flatpak ()) {
-    g_file_create_async (css_file, G_FILE_CREATE_NONE, G_PRIORITY_DEFAULT, NULL, css_file_created_cb, NULL);
-  } else {
-    ephy_file_launch_handler ("text/plain", css_file,
-                              gtk_get_current_event_time ());
-    g_object_unref (css_file);
-  }
+  g_file_create_async (css_file, G_FILE_CREATE_NONE, G_PRIORITY_DEFAULT, NULL, css_file_created_cb, NULL);
 }
 
 static void
@@ -1927,7 +1925,7 @@ setup_general_page (PrefsDialog *dialog)
   GSettings *web_settings;
 
   if (ephy_embed_shell_get_mode (ephy_embed_shell_get_default ()) == EPHY_EMBED_SHELL_MODE_APPLICATION) {
-    dialog->webapp = ephy_web_application_for_profile_directory (ephy_dot_dir ());
+    dialog->webapp = ephy_web_application_for_profile_directory (ephy_profile_dir ());
     prefs_dialog_update_webapp_icon (dialog, dialog->webapp->icon_url);
     gtk_entry_set_text (GTK_ENTRY (dialog->webapp_url), dialog->webapp->url);
     gtk_entry_set_text (GTK_ENTRY (dialog->webapp_title), dialog->webapp->name);
